% Cycloidal Gearbox Optimization Toolkit
% (C) Roman Król
% University of Technology and Humanities in Radom, Poland
% December 2018
function [jac]=GearJac(x)

    zs=15;
    zk=16;
    r=x(1)*(zs+1)/x(3);
    e=x(1);
    q=x(2);
    m=x(3);
    N=1000;
    h=x(4);
    Rs=x(5);
    Rh=x(6);
    zi=8;
    Mh=1550;
    nu1=0.3;
    nu2=0.3;
    Emod1=200000;
    Emod2=200000;
    Rw=x(7);   
    
    alp=GearAlpha(e, zk, zs, m, q, 0);
    rho=GearRho(e, zk, zs, m, q, alp);
    if rho<0
        min_alpha=alp;
        max_alpha=alp+pi/zs;
    else
        max_alpha=alp;
        min_alpha=alp+pi/zs;
    end  
    
    jac=[GearVolumede(r, e, zk, zs, q, m, N, h, Rs, Rh, zi),...
         GearVolumedq(r, e, zk, zs, q, m, N, h, Rs, Rh, zi),...
         GearVolumedm(r, e, zk, zs, q, m, N, h, Rs, Rh, zi),...
         GearVolumedh(r, e, zk, zs, q, m, N, h, Rs, Rh, zi),...
         GearVolumedRs(r, e, zk, zs, q, m, N, h, Rs, Rh, zi),...
         GearVolumedRh(r, e, zk, zs, q, m, N, h, Rs, Rh, zi),...
         0;
         GearStressExdePos(e, zk, zs, m, q, h, Mh, nu1, Emod1, nu2, Emod2, max_alpha),...
         GearStressExdqPos(e, zk, zs, m, q, h, Mh, nu1, Emod1, nu2, Emod2, max_alpha),...
         GearStressExdmPos(e, zk, zs, m, q, h, Mh, nu1, Emod1, nu2, Emod2, max_alpha),...
         GearStressExdhPos(e, zk, zs, m, q, h, Mh, nu1, Emod1, nu2, Emod2, max_alpha),...
         0,...
         0,...
         0;
         GearStressExdeNeg(e, zk, zs, m, q, h, Mh, nu1, Emod1, nu2, Emod2, min_alpha),...
         GearStressExdqNeg(e, zk, zs, m, q, h, Mh, nu1, Emod1, nu2, Emod2, min_alpha),...
         GearStressExdmNeg(e, zk, zs, m, q, h, Mh, nu1, Emod1, nu2, Emod2, min_alpha),...
         GearStressExdhNeg(e, zk, zs, m, q, h, Mh, nu1, Emod1, nu2, Emod2, min_alpha),...
         0,...
         0,...
         0;
         0,...
         0,...
         0,...
         GearStressIndh(Rs, Mh, zs, Rw, Rh, h, zi, nu1, Emod1, nu2, Emod2),...
         GearStressIndRs(Rs, Mh, zs, Rw, Rh, h, zi, nu1, Emod1, nu2, Emod2),...
         GearStressIndRh(Rs, Mh, zs, Rw, Rh, h, zi, nu1, Emod1, nu2, Emod2),...
         GearStressIndRw(Rs, Mh, zs, Rw, Rh, h, zi, nu1, Emod1, nu2, Emod2);
         GearPenaltyVminJac(r, e, zk, zs, q, m, N, h, Rs, Rh, zi)*GearVolumede(r, e, zk, zs, q, m, N, h, Rs, Rh, zi), ...
         GearPenaltyVminJac(r, e, zk, zs, q, m, N, h, Rs, Rh, zi)*GearVolumedq(r, e, zk, zs, q, m, N, h, Rs, Rh, zi), ...
         GearPenaltyVminJac(r, e, zk, zs, q, m, N, h, Rs, Rh, zi)*GearVolumedm(r, e, zk, zs, q, m, N, h, Rs, Rh, zi), ...
         GearPenaltyVminJac(r, e, zk, zs, q, m, N, h, Rs, Rh, zi)*GearVolumedh(r, e, zk, zs, q, m, N, h, Rs, Rh, zi), ...
         GearPenaltyVminJac(r, e, zk, zs, q, m, N, h, Rs, Rh, zi)*GearVolumedRs(r, e, zk, zs, q, m, N, h, Rs, Rh, zi), ...
         GearPenaltyVminJac(r, e, zk, zs, q, m, N, h, Rs, Rh, zi)*GearVolumedRh(r, e, zk, zs, q, m, N, h, Rs, Rh, zi), ...
         0;
         GearPenaltyEminJac(r, e, zk, zs, q, m, N, h, Rs, Rh, zi), 0, 0, 0, 0, 0, 0;
         0, 0, GearPenaltyMminJac(r, e, zk, zs, q, m, N, h, Rs, Rh, zi), 0, 0, 0, 0;
         0, 0, GearPenaltyMmaxJac(r, e, zk, zs, q, m, N, h, Rs, Rh, zi), 0, 0, 0, 0;
         0, 0, 0, GearPenaltyHminJac(r, e, zk, zs, q, m, N, h, Rs, Rh, zi), 0, 0, 0;
         0, 0, 0, 0, GearPenaltyRsminJac(r, e, zk, zs, q, m, N, h, Rs, Rh, zi), 0, 0;
         0, 0, 0, 0, 0, GearPenaltyRhminJac(r, e, zk, zs, q, m, N, h, Rs, Rh, zi), 0;
         0, GearPenaltyqminJac(r, e, zk, zs, q, m, N, h, Rs, Rh, zi), 0, 0, 0, 0, 0;
         0, 0, 0, 0, 0, 0, GearPenaltyRwminJac(zs, zi, h, Mh, Rw, Rs, Rh, nu1, Emod1, nu2, Emod2);
         0, 0, 0, 0, 0, 0, GearPenaltyRwmaxJac(r, zs, zi, h, Mh, Rw, Rs, Rh, nu1, Emod1, nu2, Emod2);
         -GearPenaltyRhopMinJac(e, zk, zs, m, q)*GearRhode(e, zk, zs, m, q, max_alpha), ... 
         -GearPenaltyRhopMinJac(e, zk, zs, m, q)*GearRhodq(e, zk, zs, m, q, max_alpha),...
         -GearPenaltyRhopMinJac(e, zk, zs, m, q)*GearRhodm(e, zk, zs, m, q, max_alpha), ...
         0, 0, 0, 0;
         GearPenaltyRhopMaxJac(e, zk, zs, m, q)*GearRhode(e, zk, zs, m, q, max_alpha), ...
         GearPenaltyRhopMaxJac(e, zk, zs, m, q)*GearRhodq(e, zk, zs, m, q, max_alpha), ...
         GearPenaltyRhopMaxJac(e, zk, zs, m, q)*GearRhodm(e, zk, zs, m, q, max_alpha), ...
         0, 0, 0, 0;
         GearPenaltyRhonMinJac(e, zk, zs, m, q)*GearRhode(e, zk, zs, m, q, min_alpha), ...
         GearPenaltyRhonMinJac(e, zk, zs, m, q)*GearRhodq(e, zk, zs, m, q, min_alpha), ...
         GearPenaltyRhonMinJac(e, zk, zs, m, q)*GearRhodm(e, zk, zs, m, q, min_alpha), ...
         0, 0, 0, 0;
         -GearPenaltyRhonMaxJac(e, zk, zs, m, q)*GearRhode(e, zk, zs, m, q, min_alpha), ...
         -GearPenaltyRhonMaxJac(e, zk, zs, m, q)*GearRhodq(e, zk, zs, m, q, min_alpha), ...
         -GearPenaltyRhonMaxJac(e, zk, zs, m, q)*GearRhodm(e, zk, zs, m, q, min_alpha), ...
         0, 0, 0, 0;
         GearPenaltyStressExPosJac(e, zk, zs, m, q, h, Mh, nu1, Emod1, nu2, Emod2)*GearStressExdePos(e, zk, zs, m, q, h, Mh, nu1, Emod1, nu2, Emod2, max_alpha), ...
         GearPenaltyStressExPosJac(e, zk, zs, m, q, h, Mh, nu1, Emod1, nu2, Emod2)*GearStressExdqPos(e, zk, zs, m, q, h, Mh, nu1, Emod1, nu2, Emod2, max_alpha), ...
         GearPenaltyStressExPosJac(e, zk, zs, m, q, h, Mh, nu1, Emod1, nu2, Emod2)*GearStressExdmPos(e, zk, zs, m, q, h, Mh, nu1, Emod1, nu2, Emod2, max_alpha), ...
         GearPenaltyStressExPosJac(e, zk, zs, m, q, h, Mh, nu1, Emod1, nu2, Emod2)*GearStressExdhPos(e, zk, zs, m, q, h, Mh, nu1, Emod1, nu2, Emod2, max_alpha), ...
         0, ...
         0, ...
         0;
         GearPenaltyStressExNegJac(e, zk, zs, m, q, h, Mh, nu1, Emod1, nu2, Emod2)*GearStressExdeNeg(e, zk, zs, m, q, h, Mh, nu1, Emod1, nu2, Emod2, min_alpha), ...
         GearPenaltyStressExNegJac(e, zk, zs, m, q, h, Mh, nu1, Emod1, nu2, Emod2)*GearStressExdqNeg(e, zk, zs, m, q, h, Mh, nu1, Emod1, nu2, Emod2, min_alpha), ...
         GearPenaltyStressExNegJac(e, zk, zs, m, q, h, Mh, nu1, Emod1, nu2, Emod2)*GearStressExdmNeg(e, zk, zs, m, q, h, Mh, nu1, Emod1, nu2, Emod2, min_alpha), ...
         GearPenaltyStressExNegJac(e, zk, zs, m, q, h, Mh, nu1, Emod1, nu2, Emod2)*GearStressExdhNeg(e, zk, zs, m, q, h, Mh, nu1, Emod1, nu2, Emod2, min_alpha), ...
         0, ...
         0, ...
         0;         
         0, ...
         0, ...
         0, ...
         GearPenaltyStressInJac(zs, zi, h, Mh, Rw, Rs, Rh, nu1, Emod1, nu2, Emod2)*GearStressIndh(Rs, Mh, zs, Rw, Rh, h, zi, nu1, Emod1, nu2, Emod2), ...
         GearPenaltyStressInJac(zs, zi, h, Mh, Rw, Rs, Rh, nu1, Emod1, nu2, Emod2)*GearStressIndRs(Rs, Mh, zs, Rw, Rh, h, zi, nu1, Emod1, nu2, Emod2), ...
         GearPenaltyStressInJac(zs, zi, h, Mh, Rw, Rs, Rh, nu1, Emod1, nu2, Emod2)*GearStressIndRh(Rs, Mh, zs, Rw, Rh, h, zi, nu1, Emod1, nu2, Emod2), ...
         GearPenaltyStressInJac(zs, zi, h, Mh, Rw, Rs, Rh, nu1, Emod1, nu2, Emod2)*GearStressIndRw(Rs, Mh, zs, Rw, Rh, h, zi, nu1, Emod1, nu2, Emod2)];
     
end